var servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatSettings =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatSettings.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "NoZero", "servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatSettings.html#a238c6a88b49acd32b938cdb360698e3b", null ],
    [ "NullDate", "servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatSettings.html#a2d7ed6ebb8cd1b2666d8fe1435079581", null ],
    [ "StandardDecimals", "servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatSettings.html#ad9c4adc3a0e111808b185bc17d64fc7b", null ],
    [ "TwoDigitDateStart", "servicecom_1_1sun_1_1star_1_1util_1_1NumberFormatSettings.html#a95f1c353dfa685f06a846e5c736864aa", null ]
];